==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/Faktura.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.enums.StatusFaktury;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class Faktura extends GenericDPSObject {
    /**
     * FAKTURA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * FAKTURA.OSOBA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long osobaId;

    /**
     * FAKTURA.PRACOWNIK_WPROWADZIL
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long pracownikWprowadzil;

    /**
     * FAKTURA.UMOWA_APTEKA_KWOTA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long umowaAptekaKwotaId;

    /**
     * FAKTURA.DATA_WYSTAWIENIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataWystawienia;

    /**
     * FAKTURA.DATA_WPROWADZENIA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataWprowadzenia;

    /**
     * FAKTURA.KWOTA_DOM
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwotaDom;

    /**
     * FAKTURA.KWOTA_M
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwotaM;

    /**
     * FAKTURA.NR
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nr;

    /**
     * FAKTURA.STATUS
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private StatusFaktury status;

    /**
     * FAKTURA.NR_WEW
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String nrWew;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return FAKTURA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * FAKTURA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return FAKTURA.OSOBA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * FAKTURA.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return FAKTURA.PRACOWNIK_WPROWADZIL
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPracownikWprowadzil() {
        return pracownikWprowadzil;
    }

    /**
     * FAKTURA.PRACOWNIK_WPROWADZIL
     *
     * @param pracownikWprowadzil
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPracownikWprowadzil(Long pracownikWprowadzil) {
        this.pracownikWprowadzil = pracownikWprowadzil;
    }

    /**
     * @return FAKTURA.UMOWA_APTEKA_KWOTA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getUmowaAptekaKwotaId() {
        return umowaAptekaKwotaId;
    }

    /**
     * FAKTURA.UMOWA_APTEKA_KWOTA_ID
     *
     * @param umowaAptekaKwotaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setUmowaAptekaKwotaId(Long umowaAptekaKwotaId) {
        this.umowaAptekaKwotaId = umowaAptekaKwotaId;
    }

    /**
     * @return FAKTURA.DATA_WYSTAWIENIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataWystawienia() {
        return dataWystawienia;
    }

    /**
     * FAKTURA.DATA_WYSTAWIENIA
     *
     * @param dataWystawienia
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataWystawienia(Date dataWystawienia) {
        this.dataWystawienia = dataWystawienia;
    }

    /**
     * @return FAKTURA.DATA_WPROWADZENIA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataWprowadzenia() {
        return dataWprowadzenia;
    }

    /**
     * FAKTURA.DATA_WPROWADZENIA
     *
     * @param dataWprowadzenia
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataWprowadzenia(Date dataWprowadzenia) {
        this.dataWprowadzenia = dataWprowadzenia;
    }

    /**
     * @return FAKTURA.KWOTA_DOM
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwotaDom() {
        return kwotaDom;
    }

    /**
     * FAKTURA.KWOTA_DOM
     *
     * @param kwotaDom
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwotaDom(BigDecimal kwotaDom) {
        this.kwotaDom = kwotaDom;
    }

    /**
     * @return FAKTURA.KWOTA_M
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwotaM() {
        return kwotaM;
    }

    /**
     * FAKTURA.KWOTA_M
     *
     * @param kwotaM
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwotaM(BigDecimal kwotaM) {
        this.kwotaM = kwotaM;
    }

    /**
     * @return FAKTURA.NR
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNr() {
        return nr;
    }

    /**
     * FAKTURA.NR
     *
     * @param nr
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNr(String nr) {
        this.nr = nr == null ? null : nr.trim();
    }

    /**
     * @return FAKTURA.STATUS
     * @mbggenerated 2014-03-10 10:45:37
     */
    public StatusFaktury getStatus() {
        return status;
    }

    /**
     * FAKTURA.STATUS
     *
     * @param status
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setStatus(StatusFaktury status) {
        this.status = status;
    }

    /**
     * @return FAKTURA.NR_WEW
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getNrWew() {
        return nrWew;
    }

    /**
     * FAKTURA.NR_WEW
     *
     * @param nrWew
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNrWew(String nrWew) {
        this.nrWew = nrWew == null ? null : nrWew.trim();
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Faktura other = (Faktura) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getPracownikWprowadzil() == null ? other.getPracownikWprowadzil() == null : this.getPracownikWprowadzil().equals(other.getPracownikWprowadzil()))
            && (this.getUmowaAptekaKwotaId() == null ? other.getUmowaAptekaKwotaId() == null : this.getUmowaAptekaKwotaId().equals(other.getUmowaAptekaKwotaId()))
            && (this.getDataWystawienia() == null ? other.getDataWystawienia() == null : this.getDataWystawienia().equals(other.getDataWystawienia()))
            && (this.getDataWprowadzenia() == null ? other.getDataWprowadzenia() == null : this.getDataWprowadzenia().equals(other.getDataWprowadzenia()))
            && (this.getKwotaDom() == null ? other.getKwotaDom() == null : this.getKwotaDom().equals(other.getKwotaDom()))
            && (this.getKwotaM() == null ? other.getKwotaM() == null : this.getKwotaM().equals(other.getKwotaM()))
            && (this.getNr() == null ? other.getNr() == null : this.getNr().equals(other.getNr()))
            && (this.getStatus() == null ? other.getStatus() == null : this.getStatus().equals(other.getStatus()))
            && (this.getNrWew() == null ? other.getNrWew() == null : this.getNrWew().equals(other.getNrWew()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getPracownikWprowadzil() == null) ? 0 : getPracownikWprowadzil().hashCode());
        result = prime * result + ((getUmowaAptekaKwotaId() == null) ? 0 : getUmowaAptekaKwotaId().hashCode());
        result = prime * result + ((getDataWystawienia() == null) ? 0 : getDataWystawienia().hashCode());
        result = prime * result + ((getDataWprowadzenia() == null) ? 0 : getDataWprowadzenia().hashCode());
        result = prime * result + ((getKwotaDom() == null) ? 0 : getKwotaDom().hashCode());
        result = prime * result + ((getKwotaM() == null) ? 0 : getKwotaM().hashCode());
        result = prime * result + ((getNr() == null) ? 0 : getNr().hashCode());
        result = prime * result + ((getStatus() == null) ? 0 : getStatus().hashCode());
        result = prime * result + ((getNrWew() == null) ? 0 : getNrWew().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", pracownikWprowadzil=").append(pracownikWprowadzil);
        sb.append(", umowaAptekaKwotaId=").append(umowaAptekaKwotaId);
        sb.append(", dataWystawienia=").append(dataWystawienia);
        sb.append(", dataWprowadzenia=").append(dataWprowadzenia);
        sb.append(", kwotaDom=").append(kwotaDom);
        sb.append(", kwotaM=").append(kwotaM);
        sb.append(", nr=").append(nr);
        sb.append(", status=").append(status);
        sb.append(", nrWew=").append(nrWew);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/Faktura.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import java.util.Date;
import pl.topteam.dps.enums.StatusFaktury;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class Faktura extends GenericDPSObject {
    /**
     * FAKTURA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * FAKTURA.OSOBA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long osobaId;

    /**
     * FAKTURA.PRACOWNIK_WPROWADZIL
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long pracownikWprowadzil;

    /**
     * FAKTURA.UMOWA_APTEKA_KWOTA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long umowaAptekaKwotaId;

    /**
     * FAKTURA.DATA_WYSTAWIENIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataWystawienia;

    /**
     * FAKTURA.DATA_WPROWADZENIA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataWprowadzenia;

    /**
     * FAKTURA.KWOTA_DOM
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwotaDom;

    /**
     * FAKTURA.KWOTA_M
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwotaM;

    /**
     * FAKTURA.NR
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nr;

    /**
     * FAKTURA.STATUS
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private StatusFaktury status;

    /**
     * FAKTURA.NR_WEW
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String nrWew;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return FAKTURA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * FAKTURA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return FAKTURA.OSOBA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOsobaId() {
        return osobaId;
    }

    /**
     * FAKTURA.OSOBA_ID
     *
     * @param osobaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOsobaId(Long osobaId) {
        this.osobaId = osobaId;
    }

    /**
     * @return FAKTURA.PRACOWNIK_WPROWADZIL
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPracownikWprowadzil() {
        return pracownikWprowadzil;
    }

    /**
     * FAKTURA.PRACOWNIK_WPROWADZIL
     *
     * @param pracownikWprowadzil
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPracownikWprowadzil(Long pracownikWprowadzil) {
        this.pracownikWprowadzil = pracownikWprowadzil;
    }

    /**
     * @return FAKTURA.UMOWA_APTEKA_KWOTA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getUmowaAptekaKwotaId() {
        return umowaAptekaKwotaId;
    }

    /**
     * FAKTURA.UMOWA_APTEKA_KWOTA_ID
     *
     * @param umowaAptekaKwotaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setUmowaAptekaKwotaId(Long umowaAptekaKwotaId) {
        this.umowaAptekaKwotaId = umowaAptekaKwotaId;
    }

    /**
     * @return FAKTURA.DATA_WYSTAWIENIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataWystawienia() {
        return dataWystawienia;
    }

    /**
     * FAKTURA.DATA_WYSTAWIENIA
     *
     * @param dataWystawienia
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataWystawienia(Date dataWystawienia) {
        this.dataWystawienia = dataWystawienia;
    }

    /**
     * @return FAKTURA.DATA_WPROWADZENIA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataWprowadzenia() {
        return dataWprowadzenia;
    }

    /**
     * FAKTURA.DATA_WPROWADZENIA
     *
     * @param dataWprowadzenia
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataWprowadzenia(Date dataWprowadzenia) {
        this.dataWprowadzenia = dataWprowadzenia;
    }

    /**
     * @return FAKTURA.KWOTA_DOM
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwotaDom() {
        return kwotaDom;
    }

    /**
     * FAKTURA.KWOTA_DOM
     *
     * @param kwotaDom
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwotaDom(BigDecimal kwotaDom) {
        this.kwotaDom = kwotaDom;
    }

    /**
     * @return FAKTURA.KWOTA_M
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwotaM() {
        return kwotaM;
    }

    /**
     * FAKTURA.KWOTA_M
     *
     * @param kwotaM
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwotaM(BigDecimal kwotaM) {
        this.kwotaM = kwotaM;
    }

    /**
     * @return FAKTURA.NR
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNr() {
        return nr;
    }

    /**
     * FAKTURA.NR
     *
     * @param nr
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNr(String nr) {
        this.nr = nr == null ? null : nr.trim();
    }

    /**
     * @return FAKTURA.STATUS
     * @mbggenerated 2014-03-13 16:02:38
     */
    public StatusFaktury getStatus() {
        return status;
    }

    /**
     * FAKTURA.STATUS
     *
     * @param status
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setStatus(StatusFaktury status) {
        this.status = status;
    }

    /**
     * @return FAKTURA.NR_WEW
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getNrWew() {
        return nrWew;
    }

    /**
     * FAKTURA.NR_WEW
     *
     * @param nrWew
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNrWew(String nrWew) {
        this.nrWew = nrWew == null ? null : nrWew.trim();
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        Faktura other = (Faktura) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getOsobaId() == null ? other.getOsobaId() == null : this.getOsobaId().equals(other.getOsobaId()))
            && (this.getPracownikWprowadzil() == null ? other.getPracownikWprowadzil() == null : this.getPracownikWprowadzil().equals(other.getPracownikWprowadzil()))
            && (this.getUmowaAptekaKwotaId() == null ? other.getUmowaAptekaKwotaId() == null : this.getUmowaAptekaKwotaId().equals(other.getUmowaAptekaKwotaId()))
            && (this.getDataWystawienia() == null ? other.getDataWystawienia() == null : this.getDataWystawienia().equals(other.getDataWystawienia()))
            && (this.getDataWprowadzenia() == null ? other.getDataWprowadzenia() == null : this.getDataWprowadzenia().equals(other.getDataWprowadzenia()))
            && (this.getKwotaDom() == null ? other.getKwotaDom() == null : this.getKwotaDom().equals(other.getKwotaDom()))
            && (this.getKwotaM() == null ? other.getKwotaM() == null : this.getKwotaM().equals(other.getKwotaM()))
            && (this.getNr() == null ? other.getNr() == null : this.getNr().equals(other.getNr()))
            && (this.getStatus() == null ? other.getStatus() == null : this.getStatus().equals(other.getStatus()))
            && (this.getNrWew() == null ? other.getNrWew() == null : this.getNrWew().equals(other.getNrWew()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getOsobaId() == null) ? 0 : getOsobaId().hashCode());
        result = prime * result + ((getPracownikWprowadzil() == null) ? 0 : getPracownikWprowadzil().hashCode());
        result = prime * result + ((getUmowaAptekaKwotaId() == null) ? 0 : getUmowaAptekaKwotaId().hashCode());
        result = prime * result + ((getDataWystawienia() == null) ? 0 : getDataWystawienia().hashCode());
        result = prime * result + ((getDataWprowadzenia() == null) ? 0 : getDataWprowadzenia().hashCode());
        result = prime * result + ((getKwotaDom() == null) ? 0 : getKwotaDom().hashCode());
        result = prime * result + ((getKwotaM() == null) ? 0 : getKwotaM().hashCode());
        result = prime * result + ((getNr() == null) ? 0 : getNr().hashCode());
        result = prime * result + ((getStatus() == null) ? 0 : getStatus().hashCode());
        result = prime * result + ((getNrWew() == null) ? 0 : getNrWew().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", osobaId=").append(osobaId);
        sb.append(", pracownikWprowadzil=").append(pracownikWprowadzil);
        sb.append(", umowaAptekaKwotaId=").append(umowaAptekaKwotaId);
        sb.append(", dataWystawienia=").append(dataWystawienia);
        sb.append(", dataWprowadzenia=").append(dataWprowadzenia);
        sb.append(", kwotaDom=").append(kwotaDom);
        sb.append(", kwotaM=").append(kwotaM);
        sb.append(", nr=").append(nr);
        sb.append(", status=").append(status);
        sb.append(", nrWew=").append(nrWew);
        sb.append("]");
        return sb.toString();
    }
}
